/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2025 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.20.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for the Renesas R7FA8D1 EK_RA8D1 eval board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED1_PIN           (0)   // User LED1, Blue, P600
#define LED1_PORT          (6)

#define LED2_PIN           (14)  // User LED2, Green, P414
#define LED2_PORT          (4)

#define LED3_PIN           (7)   // User LED3, Red, P107
#define LED3_PORT          (1)

#define PORT_BASE_ADDR     (0x40400000u)
#define PORT_PODR(x)       (*(volatile unsigned short*)(PORT_BASE_ADDR + (0x20u * x) + 0x02u))           // Control Register 1 Output Data
#define PORT_PDR(x)        (*(volatile unsigned short*)(PORT_BASE_ADDR + (0x20u * x) + 0x00u))           // Control Register 1 Direction
#define PORT_PORR(x)       (*(volatile unsigned short*)(PORT_BASE_ADDR + (0x20u * x) + 0x0Au))           // Control Register 3 Output Reset
#define PORT_POSR(x)       (*(volatile unsigned short*)(PORT_BASE_ADDR + (0x20u * x) + 0x08u))           // Control Register 3 Output Set

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Set pins to output
  //
  PORT_PDR(LED1_PORT) |= (1u << LED1_PIN);
  PORT_PDR(LED2_PORT) |= (1u << LED2_PIN);
  PORT_PDR(LED3_PORT) |= (1u << LED3_PIN);
  //
  // Clear Leds
  //
  PORT_PORR(LED1_PORT) = (1u << LED1_PIN);
  PORT_PORR(LED2_PORT) = (1u << LED2_PIN);
  PORT_PORR(LED3_PORT) = (1u << LED3_PIN);
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
  case 0:
    PORT_POSR(LED1_PORT) = (1u << LED1_PIN);
    break;
  case 1:
    PORT_POSR(LED2_PORT) = (1u << LED2_PIN);
    break;
  case 2:
    PORT_POSR(LED3_PORT) = (1u << LED3_PIN);
    break;
  default:
    break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
  case 0:
    PORT_PORR(LED1_PORT) = (1u << LED1_PIN);
    break;
  case 1:
    PORT_PORR(LED2_PORT) = (1u << LED2_PIN);
    break;
  case 2:
    PORT_PORR(LED3_PORT) = (1u << LED3_PIN);
    break;
  default:
    break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
  case 0:
    if ((PORT_PODR(LED1_PORT) & (1u << LED1_PIN)) != 0) {
      PORT_PORR(LED1_PORT) = (1u << LED1_PIN);
    } else {
      PORT_POSR(LED1_PORT) = (1u << LED1_PIN);
    }
    break;
  case 1:
    if ((PORT_PODR(LED2_PORT) & (1u << LED2_PIN)) != 0) {
      PORT_PORR(LED2_PORT) = (1u << LED2_PIN);
    } else {
      PORT_POSR(LED2_PORT) = (1u << LED2_PIN);
    }
    break;
  case 2:
    if ((PORT_PODR(LED3_PORT) & (1u << LED3_PIN)) != 0) {
      PORT_PORR(LED3_PORT) = (1u << LED3_PIN);
    } else {
      PORT_POSR(LED3_PORT) = (1u << LED3_PIN);
    }
    break;
  default:
    break;
  }
}

/*************************** End of file ****************************/
